SystemOrganization addCategory: #'Versionner-Core-Model'!

Object subclass: #MBConfigurationRoot
	instanceVariableNames: 'announcer configurations username password'
	classVariableNames: 'Current'
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBConfigurationRoot commentStamp: '<historical>' prior: 0!
MB stands for Metacello Borwser.
MBConfigurationRoot is the root object holding information on all available configurations in the image.

Instance Variables
	announcer:		<Object>
	configurations:	a collection of MBConfigurationInfo.
	password:		<Object>
	username:		<Object>
!

!MBConfigurationRoot class methodsFor: 'accessing' stamp: 'JuanPabloSandovalAlcocer 6/30/2012 23:11'!
current
	"singleton pattern"
	Current ifNil: [ 
		Current := self new.
		Current register ].
	^Current ! !

!MBConfigurationRoot class methodsFor: 'accessing' stamp: 'dkh 3/10/2011 18:22'!
reset
	"self reset"
	| c |
	Current ifNil: [ ^self ].
	c := Current.
	Current := nil.
	c unregister.
! !

!MBConfigurationRoot methodsFor: 'actions' stamp: 'dkh 3/10/2011 12:49'!
addConfigurationInfoFor: aConfigurationClass
	(self configurationInfoFor: aConfigurationClass) notNil
		ifTrue: [ ^ self ].
	self configurations
		add:
			((MBConfigurationInfo configurationClass: aConfigurationClass)
				configurationRoot: self;
				yourself).
	self announcer announce: MBConfigurationInfoCreated! !

!MBConfigurationRoot methodsFor: 'accessing' stamp: 'dkh 3/10/2011 12:37'!
announcer

	^announcer ! !

!MBConfigurationRoot methodsFor: 'updating' stamp: 'JuanPabloSandovalA 8/15/2012 14:16'!
classAdded: anEvent

	(anEvent classAdded name asString beginsWith: 'ConfigurationOf')
		ifTrue: [ self respondToEventFor: anEvent classAdded withOperation: #added ]! !

!MBConfigurationRoot methodsFor: 'updating' stamp: 'JuanPabloSandovalA 8/15/2012 15:10'!
classModified: anEvent
	
	(anEvent classAffected name asString beginsWith: 'ConfigurationOf')
		ifTrue: [ self respondToEventFor: anEvent classAffected withOperation: #modified ]! !

!MBConfigurationRoot methodsFor: 'updating' stamp: 'JuanPabloSandovalA 8/15/2012 14:15'!
classRemoved: anEvent

	(anEvent classRemoved name asString beginsWith: 'ConfigurationOf')
		ifTrue: [ self respondToEventFor: anEvent classRemoved withOperation: #removed ]! !

!MBConfigurationRoot methodsFor: 'accessing' stamp: 'dkh 3/5/2011 15:33'!
configurationClasses
	^ MetacelloToolBox configurationClasses! !

!MBConfigurationRoot methodsFor: 'accessing' stamp: 'dkh 4/9/2011 18:26'!
configurationInfoFor: aConfigurationClass

	self configurations do: [:info | info configurationClass == aConfigurationClass theNonMetaClass  ifTrue: [ ^info ]].
	^nil! !

!MBConfigurationRoot methodsFor: 'accessing' stamp: 'dkh 3/6/2011 14:51'!
configurations
	configurations
		ifNil: [ 
			configurations := (self configurationClasses
				collect: [ :cls | 
					(MBConfigurationInfo configurationClass: cls)
						configurationRoot: self;
						yourself ]) asSortedCollection: [ :a :b | a name <= b name ] ].
	^ configurations! !

!MBConfigurationRoot methodsFor: 'initialize-release' stamp: 'dkh 3/10/2011 12:37'!
initialize

	super initialize .
	announcer := Announcer new! !

!MBConfigurationRoot methodsFor: 'updating' stamp: 'NorbertHartl 4/9/2013 10:30'!
methodModified: anEvent

	(anEvent methodClass name asString beginsWith: 'ConfigurationOf')
		ifTrue: [  self respondToEventFor: anEvent methodClass withOperation: #modified ]! !

!MBConfigurationRoot methodsFor: 'accessing' stamp: 'dkh 3/5/2011 15:34'!
password
	^ password! !

!MBConfigurationRoot methodsFor: 'accessing' stamp: 'dkh 3/5/2011 15:34'!
password: anObject
	password := anObject! !

!MBConfigurationRoot methodsFor: 'updating' stamp: 'JuanPabloSandovalA 8/15/2012 15:00'!
register
	"Set up dependencies"
	
	SystemAnnouncer uniqueInstance weak
		on: ClassAdded send: #classAdded: to: self;
		on: ClassModifiedClassDefinition,
			ClassCommented,
			ClassRenamed, 
			ClassReorganized,
			ClassRenamed send: #classModified: to: self;
		on: ClassRemoved send: #classRemoved: to: self;		
		on: MethodAdded,
			MethodModified ,
			MethodRemoved send: #methodModified: to: self.
	MCWorkingCopy addDependent: self.! !

!MBConfigurationRoot methodsFor: 'actions' stamp: 'dkh 3/10/2011 14:46'!
removeConfigurationInfo: aConfigurationInfo

	aConfigurationInfo release.
	self configurations remove: aConfigurationInfo ifAbsent: [].
	self announcer announce: MBConfigurationInfoDeleted! !

!MBConfigurationRoot methodsFor: 'updating' stamp: 'JuanPabloSandovalA 8/15/2012 15:13'!
respondToEventFor: aConfigurationClass withOperation: operation
	"Events generated by SystemChangeNotifier and involve edits to the configuration itself."

	| info |
	operation == #added
		ifTrue: [ ^self addConfigurationInfoFor: aConfigurationClass ].
	(info := self configurationInfoFor: aConfigurationClass) isNil
		ifTrue: [ ^ self ].
	operation == #removed
		ifTrue: [ ^self removeConfigurationInfo: info ].
	"operation == #modified...configuration specs potentially modified"
	info configurationClassModified.
	self configurations do: [ :configInfo | configInfo recalculateIfInterestedInConfigurationInfo: info for: operation ]! !

!MBConfigurationRoot methodsFor: 'updating' stamp: 'JuanPabloSandovalA 8/15/2012 14:36'!
unregister
	"Unregister from the dependent object. Typically used when closing the browser"
	
	SystemAnnouncer uniqueInstance unsubscribe: self.
	MCWorkingCopy removeDependent: self.
! !

!MBConfigurationRoot methodsFor: 'updating' stamp: 'dkh 4/7/2011 23:42'!
update: anArrayOrSymbol
	"A package has been modified (loaded, removed, or updated). Find out if any configurations are managing the package.
	Update events are coming from MCWorkingCopy."

	| packageName operation |
	anArrayOrSymbol isArray
		ifFalse: [ ^ self ].
	operation := anArrayOrSymbol at: 1.
	operation == #modified
		ifTrue: [ packageName := (anArrayOrSymbol at: 2) packageName ].
	operation == #registered
		ifTrue: [ packageName := (anArrayOrSymbol at: 2) name ].
	operation == #unregistered
		ifTrue: [ packageName := (anArrayOrSymbol at: 2) name ].
	(packageName beginsWith: 'ConfigurationOf')
		ifTrue: [ 
			| wc info |
			operation ~~ #modified
				ifTrue: [ ^ self ].	"only interested in modified"
			wc := anArrayOrSymbol at: 2.
			wc modified
				ifTrue: [ ^ self ].	"only interested in transtion from modified to not modified"
			(info := self configurationInfoFor: (Smalltalk at: packageName asSymbol ifAbsent: [ ^ self ])) isNil
				ifTrue: [ ^ self ].	
			"removed and added packages handled by the add/removal of the class"
			info configurationClassModified.
			^ self ].
	self configurations do: [ :info | info recalculateIfInterestedInPackageNamed: packageName for: operation ]! !

!MBConfigurationRoot methodsFor: 'accessing' stamp: 'dkh 3/5/2011 15:35'!
username
	^ username! !

!MBConfigurationRoot methodsFor: 'accessing' stamp: 'dkh 3/5/2011 15:35'!
username: anObject
	username := anObject! !

Object subclass: #MBInfo
	instanceVariableNames: 'name text validationResult validationIcon validationIconSymbol'
	classVariableNames: 'ValidateAll'
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

MBInfo subclass: #MBAbstractInfoList
	instanceVariableNames: 'packages projects groups infoList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBAbstractInfoList commentStamp: '<historical>' prior: 0!
A MBAbstractInfoList is an abstraction used to hold information on groups, packages and projects.

Instance Variables
	groups:		a list of groups (MBGroupInfo instances)
	infoList:		<Object>
	packages:		<Object>
	projects:		<Object>
!

!MBAbstractInfoList methodsFor: 'private' stamp: 'dkh 3/2/2011 20:03'!
calculateInfoList

	^self subclassResponsibility ! !

!MBAbstractInfoList methodsFor: 'updating' stamp: 'dkh 03/14/2011 07:17'!
fullRecalculate

	self recalculate! !

!MBAbstractInfoList methodsFor: 'accessing-computed' stamp: 'dkh 3/6/2011 15:34'!
groups
	"Return the list of groups for the configuration"

	| groupSpecs |
	groups ~~ nil
		ifTrue: [ ^ groups ].
	groups := OrderedCollection new.
	self versionForInfoList ifNil: [ ^ groups ].
	groupSpecs := self versionForInfoList groups.
	groupSpecs := groupSpecs asSortedCollection: [ :a :b | a name <= b name ].
	groups
		addAll:
			(groupSpecs
				collect: [ :grpSpec | 
					(MBGroupInfo spec: grpSpec)
						configurationInfo: self configurationInfo;
						yourself ]).
	^ groups! !

!MBAbstractInfoList methodsFor: 'accessing-computed' stamp: 'dkh 3/10/2011 16:00'!
infoList
	infoList ~~ nil ifTrue: [ ^infoList ].
	^ infoList := self calculateInfoList! !

!MBAbstractInfoList methodsFor: 'accessing-computed' stamp: 'AlexandreBergel 1/17/2012 17:34'!
infos
	"Return the list of info that are displayed"
	^self infoList! !

!MBAbstractInfoList methodsFor: 'updating' stamp: 'dkh 4/12/2011 10:54'!
interestedInPackage: operation
	"potential currentVersion change"
	
	self fullRecalculate.
	^true! !

!MBAbstractInfoList methodsFor: 'updating' stamp: 'dkh 3/2/2011 20:14'!
interestedInPackageNamed: packageName
	packages notNil
		ifTrue: [ 
			(self packages detect: [ :info | info interestedInPackageNamed: packageName ] ifNone: [  ]) notNil
				ifTrue: [ ^ true ] ].
	^ false! !

!MBAbstractInfoList methodsFor: 'testing' stamp: 'dkh 3/9/2011 22:15'!
isDirty
	^ self packages anySatisfy: [:each | each isDirty ]! !

!MBAbstractInfoList methodsFor: 'accessing-computed' stamp: 'AlexandreBergel 8/2/2011 16:37'!
packages
	"Return the list of dependent packages for the last baseline"

	| packageSpecs |
	packages ~~ nil
		ifTrue: [ ^ packages ].
	self versionForInfoList ifNil: [ ^ #() ].
	packages := OrderedCollection new.
	packageSpecs := self versionForInfoList packages.
	packageSpecs := packageSpecs asSortedCollection: [ :a :b | a name <= b name ].
	packages
		addAll:
			(packageSpecs
				collect: [ :pkgSpec | 
					| packageName |
					(packageName := pkgSpec getFile) ifNil: [ packageName := pkgSpec name asString ].
					(MBPackageInfo named: packageName packageName: pkgSpec name asString spec: pkgSpec)
						configurationInfo: self configurationInfo;
						yourself ]).
	^ packages! !

!MBAbstractInfoList methodsFor: 'accessing-computed' stamp: 'dkh 3/6/2011 15:34'!
projects
	"Return the list of dependent packages for the last baseline"

	| projectSpecs |
	projects ~~ nil
		ifTrue: [ ^ projects ].
	projects := OrderedCollection new.
	self versionForInfoList ifNil: [ ^ projects ].
	projectSpecs := self versionForInfoList projects.
	projectSpecs := projectSpecs asSortedCollection: [ :a :b | a name <= b name ].
	projects
		addAll:
			(projectSpecs
				collect: [ :prjSpec | 
					(MBProjectInfo named: prjSpec name packageName: prjSpec projectPackage name spec: prjSpec)
						configurationInfo: self configurationInfo;
						yourself ]).
	^ projects! !

!MBAbstractInfoList methodsFor: 'updating' stamp: 'dkh 3/10/2011 18:30'!
recalculate

	text := groups := validationResult := validationIcon := projects:= packages := nil.
	infoList == nil ifTrue: [ ^self ].
	self announcer announce: (MBInfoListChanged changed: self).
	infoList := nil! !

!MBAbstractInfoList methodsFor: 'updating' stamp: 'dkh 4/12/2011 10:46'!
recalculateIfInterestedInPackageNamed: packageName for: operation
	"keep projects separate, since I'm the only one interested in projects."
	(self interestedInPackageNamed: packageName)
		ifTrue: [ ^self interestedInPackage: operation ].
	projects notNil
		ifTrue: [ 
			(self projects detect: [ :info | info interestedInPackageNamed: packageName ] ifNone: [  ]) notNil
				ifTrue: [ ^self interestedInPackage: operation ] ].
	^false! !

!MBAbstractInfoList methodsFor: 'initialize-release' stamp: 'dkh 3/6/2011 18:38'!
release

	| baselines versions |
	super release.
	packages := projects := groups := infoList := nil.! !

!MBAbstractInfoList methodsFor: 'accessing-computed' stamp: 'dkh 3/2/2011 20:29'!
versionForInfoList

	^self subclassResponsibility ! !

MBAbstractInfoList subclass: #MBAbstractVersionInfo
	instanceVariableNames: 'configurationInfo version'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBAbstractVersionInfo class methodsFor: 'instance creation' stamp: 'AlexandreBergel 3/1/2011 08:49'!
new
	self error: 'Please use version:browser: or version: instead'! !

!MBAbstractVersionInfo class methodsFor: 'instance creation' stamp: 'dkh 3/6/2011 15:32'!
version: aMetacelloVersion

	^ super new 
		version: aMetacelloVersion;
		yourself! !

!MBAbstractVersionInfo methodsFor: 'private' stamp: 'dkh 3/2/2011 20:31'!
calculateInfoList
	| answer list cvs cv |
	answer := OrderedCollection new.
	cvs := ''.
	(cv := self versionForInfoList) ~~ nil
		ifTrue:  [cvs := cv versionString, ' '].
	(list := self projects) notEmpty
		ifTrue: [ 
			answer add: (MBLabelInfo new name: ' -- ', cvs, 'projects --').
			answer addAll: list.
			answer add: (MBLabelInfo new name: '') ].
	(list := self packages) notEmpty
		ifTrue: [ 
			answer add: (MBLabelInfo new name: ' -- ', cvs, 'packages --').
			answer addAll: list.
			answer add: (MBLabelInfo new name: '') ].
	(list := self groups) notEmpty
		ifTrue: [ 
			answer add: (MBLabelInfo new name: ' -- ', cvs, 'groups --').
			answer addAll: list].
	^ answer! !

!MBAbstractVersionInfo methodsFor: 'commands' stamp: 'fds 2/26/2011 19:53'!
cmdAddBaseline
	^ MBAddBaselineCommand! !

!MBAbstractVersionInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 04:58'!
cmdAddDevelopmentVersion
	<command>
	^ MBAddDevelopmentVersionCommand! !

!MBAbstractVersionInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 04:59'!
cmdBrowse
	<command>
	^ MBBrowseCommand! !

!MBAbstractVersionInfo methodsFor: 'commands' stamp: 'dkh 4/7/2011 22:25'!
cmdCreateBranchVersion
	<command>
	^ MBBranchConfigurationCommand! !

!MBAbstractVersionInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 04:59'!
cmdLoad
	<command>
	^ MBLoadCommand! !

!MBAbstractVersionInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 04:59'!
cmdRemove
	<command>
	^ MBRemoveCommand! !

!MBAbstractVersionInfo methodsFor: 'commands' stamp: 'AlexandreBergel 4/15/2011 09:24'!
cmdSaveAllPackagesAndAddVersion
	<command>
	^ MBSaveAllPackagesAndAddVersionCommand! !

!MBAbstractVersionInfo methodsFor: 'commands' stamp: 'dkh 4/3/2011 17:25'!
cmdSetCurrentVersion
	<command>
	^ MBSetCurrentVersionCommand! !

!MBAbstractVersionInfo methodsFor: 'accessing' stamp: 'dkh 3/2/2011 08:04'!
configurationBasename
	^ MBToolBox baseNameOfConfiguration: self configurationClass! !

!MBAbstractVersionInfo methodsFor: 'accessing' stamp: 'dkh 3/5/2011 17:55'!
configurationClass
	^ self configurationInfo configurationClass! !

!MBAbstractVersionInfo methodsFor: 'accessing' stamp: 'dkh 3/5/2011 17:50'!
configurationInfo
	^ configurationInfo! !

!MBAbstractVersionInfo methodsFor: 'accessing' stamp: 'dkh 3/5/2011 17:50'!
configurationInfo: anObject
	configurationInfo := anObject! !

!MBAbstractVersionInfo methodsFor: 'accessing' stamp: 'dkh 3/5/2011 17:56'!
currentVersion

	^self configurationInfo currentVersion! !

!MBAbstractVersionInfo methodsFor: 'testing' stamp: 'dkh 3/1/2011 21:08'!
hasValidationIssues
	validationResult == nil ifTrue: [ ^false ].
	^validationResult notEmpty! !

!MBAbstractVersionInfo methodsFor: 'testing' stamp: 'dkh 3/2/2011 16:43'!
isBleedingEdge
	^  (self project hasVersion: #bleedingEdge) and: [
		(self project version: #bleedingEdge) = self version ]! !

!MBAbstractVersionInfo methodsFor: 'as yet unclassified' stamp: 'JuanPabloSandovalAlcocer 1/8/2012 18:10'!
isCurrentVersion
	|cv|
	(cv := self currentVersion) ~~ nil
		ifTrue: [ 
			cv = self version
				ifTrue: [^ true]].
	^false.! !

!MBAbstractVersionInfo methodsFor: 'testing' stamp: 'dkh 3/2/2011 16:44'!
isDevelopment
	^  (self project hasVersion: #development) and: [
		(self project version: #development) = self version ]! !

!MBAbstractVersionInfo methodsFor: 'testing' stamp: 'dkh 3/2/2011 16:43'!
isStable
	^ (self project hasVersion: #stable) and: [ 
		(self project version: #stable) = self version ]! !

!MBAbstractVersionInfo methodsFor: 'printing' stamp: 'dkh 3/6/2011 15:15'!
printOn: aStream
	| cv |
	(cv := self currentVersion) ~~ nil
		ifTrue: [ 
			cv = self version
				ifTrue: [ aStream nextPutAll: ' @ ' ] ].
	super printOn: aStream.
! !

!MBAbstractVersionInfo methodsFor: 'accessing' stamp: 'dkh 3/2/2011 16:42'!
project
	"Answer the MetacelloProject associated with the receiver."
	
	^self version project! !

!MBAbstractVersionInfo methodsFor: 'accessing' stamp: 'dkh 3/2/2011 16:44'!
validate
	validationResult == nil
		ifTrue: [ 
			validationIcon := nil.
			validationResult := MetacelloToolBox validateProject: self project version: self version versionString ].
	^ validationResult! !

!MBAbstractVersionInfo methodsFor: 'accessing' stamp: 'dkh 2/23/2011 12:57'!
version
	^ version! !

!MBAbstractVersionInfo methodsFor: 'accessing' stamp: 'dkh 2/23/2011 14:13'!
version: aMetacelloVersion

	version := aMetacelloVersion.
	self name: aMetacelloVersion versionString.
	
! !

!MBAbstractVersionInfo methodsFor: 'accessing-computed' stamp: 'dkh 3/2/2011 20:29'!
versionForInfoList

	^self version ! !

!MBAbstractVersionInfo methodsFor: 'accessing' stamp: 'dkh 3/19/2011 10:42'!
versionString
	^ self version versionString! !

MBAbstractVersionInfo subclass: #MBBaselineInfo
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBBaselineInfo commentStamp: '<historical>' prior: 0!
A MBBaselineInfo holds information on a baselinf of a configuration.

!

!MBBaselineInfo class methodsFor: 'accessing' stamp: 'dkh 4/10/2011 19:56'!
helpLabel

	^'Baseline'! !

!MBBaselineInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 04:59'!
cmdCopyBaseline
	<command>
	^ MBCopyBaselineCommand! !

!MBBaselineInfo methodsFor: 'printing' stamp: 'DaleHenrichs 2/24/2011 18:23'!
printOn: aStream
	super printOn: aStream.
	self isBleedingEdge 
		ifTrue: [ aStream nextPutAll: ' #bleedingEdge' ].! !

MBAbstractVersionInfo subclass: #MBVersionInfo
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBVersionInfo class methodsFor: 'accessing' stamp: 'dkh 4/10/2011 19:56'!
helpLabel

	^'Version'! !

!MBVersionInfo methodsFor: 'commands' stamp: 'dkh 3/20/2011 16:34'!
cmdAddDescriptionVersion
	<command>
	^ MBAddDescriptionCommand! !

!MBVersionInfo methodsFor: 'commands' stamp: 'dkh 4/7/2011 15:40'!
cmdArchiveVersion
	<command>
	^ MBArchiveVersionCommand! !

!MBVersionInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 04:59'!
cmdCompareToCurrentVersion
	<command>
	^ MBCompareToCurrentVersionCommand! !

!MBVersionInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 04:59'!
cmdCompareToStableVersion
	<command>
	^ MBCompareToStableVersionCommand! !

!MBVersionInfo methodsFor: 'commands' stamp: 'dkh 4/11/2011 17:00'!
cmdOpenForDevelopment
	<command>
	^ MBOpenForDevelopmentCommand! !

!MBVersionInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 05:00'!
cmdReleaseDevelopmentVersion
	<command>
	^ MBReleaseDevelopmentVersionCommand! !

!MBVersionInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 05:00'!
cmdSetDescription
	<command>
	^ MBSetDescriptionCommand! !

!MBVersionInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 05:00'!
cmdUpdatePackage
	<command>
	^ MBUpdatePackageCommand! !

!MBVersionInfo methodsFor: 'commands' stamp: 'dkh 4/10/2011 12:40'!
cmdUpdateProject
	<command>
	^ MBUpdateProjectCommand! !

!MBVersionInfo methodsFor: 'printing' stamp: 'dkh 2/24/2011 15:33'!
printOn: aStream
	super printOn: aStream.
	self isDevelopment 
		ifTrue: [ 
			aStream nextPutAll: ' #development'.
			^self ].
	self isStable
		ifTrue: [ aStream nextPutAll: ' #stable' ].! !

MBAbstractInfoList subclass: #MBConfigurationInfo
	instanceVariableNames: 'configurationRoot branch configurationClass currentVersion baselines versions workingCopy trimVersionLists'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBConfigurationInfo commentStamp: '<historical>' prior: 0!
A MBConfigurationInfo holds information on a specific configuration, i.e. on the ConfigurationOf class of a project.

Instance Variables
	baselines:		list of baselines (MBBaseLineInfo instances) of this configuration.
	branch:			??
	configurationClass:	the configuration class (ConfigurationOf instance).
	configurationRoot:		a link to the root object with all configurations.
	currentVersion:		??
	trimVersionLists:		true if ??
	versions:			list of versions (MBVersionInfo instances) of this configuration.
	workingCopy:	the Metacello working copy
!

!MBConfigurationInfo class methodsFor: 'instance creation' stamp: 'AlexandreBergel 1/16/2011 21:14'!
configurationClass: aConfiguration
	^ super new 
		configurationClass: aConfiguration;
		yourself! !

!MBConfigurationInfo class methodsFor: 'accessing' stamp: 'dkh 4/10/2011 19:56'!
helpLabel

	^'Configuration'! !

!MBConfigurationInfo class methodsFor: 'instance creation' stamp: 'AlexandreBergel 1/16/2011 21:13'!
new
	self error: 'Please, use #configuration: to instantiate ', self name printString! !

!MBConfigurationInfo methodsFor: 'accessing-computed' stamp: 'dkh 3/6/2011 15:00'!
baselines 
	baselines ~~ nil ifTrue: [ ^baselines ].
	baselines := self baselinesFor: self project.
	^baselines ! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'dkh 3/6/2011 15:33'!
baselinesFor: aMetacelloProject
	"Return the list of  BaselineInfo for the configuration class passed as parameter"

	"The returned collection is ordered. Labeled baselines are first, numbered baselines are last"

	| existingBaselines numberedBaselines labeledBaselines |
	existingBaselines := aMetacelloProject versions select: [ :vrsn | vrsn blessing == #baseline ].
	existingBaselines := existingBaselines
		collect: [ :vrsn | 
			(MBBaselineInfo version: vrsn)
				configurationInfo: self;
				yourself ].
	numberedBaselines := existingBaselines select: [ :bInfo | ($0 to: $9) includes: bInfo name first ].
	labeledBaselines := existingBaselines copyWithoutAll: numberedBaselines.
	^ labeledBaselines asArray , numberedBaselines asArray reversed! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'dkh 4/7/2011 23:57'!
branch

	branch ifNil: [ branch := self extractBranchFrom: self workingCopy ].
	^branch! !

!MBConfigurationInfo methodsFor: 'converting' stamp: 'dkh 4/5/2011 16:41'!
buildStringOrText
	| string cv specVersion attributes wc |
	attributes := OrderedCollection new.
	[ string := super buildStringOrText ]
		on: Error
		do: [ :ex | 
			attributes add: TextEmphasis struckOut.
			^ Text string: self name asString attributes: attributes ].
	((wc := self workingCopy) notNil and: [ wc needsSaving ])
		ifTrue: [ attributes add: TextEmphasis underlined ].
	self currentVersion. "prime the pump"
	currentVersion == #notLoaded
		ifTrue: [ 
			attributes notEmpty
				ifTrue: [ ^ Text string: string attributes: attributes ].
			^ string ].
	super isDirty | self currentVersionMismatch
		ifTrue: [ attributes add: TextEmphasis bold ].
	self currentVersion versionStatus == #somethingLoaded
		ifTrue: [ attributes add: TextColor red ].
	attributes notEmpty
		ifTrue: [ ^ Text string: string attributes: attributes ].
	^ string! !

!MBConfigurationInfo methodsFor: 'private' stamp: 'dkh 3/18/2011 18:42'!
calculateInfoList
	| answer list cvs cv |
	answer := OrderedCollection new.
	[self project ifNil: [ ^answer ]] on: Error do: [:ex | ^answer ].
	answer add: (MBLabelInfo new name: ' -- baselines --').
	answer addAll: (self trimVersionInfos: self baselines).
	answer add: (MBLabelInfo new name: '').
	answer add: (MBLabelInfo new name: ' -- versions --').
	answer addAll: (self trimVersionInfos: self versions).
	answer add: (MBLabelInfo new name: '').
	cvs := ''.
	(cv := self currentVersion) ~~ nil
		ifTrue:  [cvs := cv versionString, ' '].
	(list := self projects) notEmpty
		ifTrue: [ 
			answer add: (MBLabelInfo new name: ' -- ', cvs, 'projects --').
			answer addAll: list.
			answer add: (MBLabelInfo new name: '') ].
	(list := self packages) notEmpty
		ifTrue: [ 
			answer add: (MBLabelInfo new name: ' -- ', cvs, 'packages --').
			answer addAll: list.
			answer add: (MBLabelInfo new name: '') ].
	(list := self groups) notEmpty
		ifTrue: [ 
			answer add: (MBLabelInfo new name: ' -- ', cvs, 'groups --').
			answer addAll: list].
	^ answer! !

!MBConfigurationInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 06:07'!
cmdBrowseConfiguration
	<command>
	^ MBBrowseConfigurationCommand! !

!MBConfigurationInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 06:07'!
cmdOpenRepository
	<command>
	^ MBOpenRepositoryCommand! !

!MBConfigurationInfo methodsFor: 'commands' stamp: 'JPSA 2/6/2012 10:43'!
cmdSaveAsCache
	<command>
	^ MBSaveAsCacheCommand! !

!MBConfigurationInfo methodsFor: 'commands' stamp: 'JuanPabloSandovalAlcocer 6/30/2012 18:07'!
cmdSaveConfiguration
	<command>
	^ MBSaveConfigurationCommand! !

!MBConfigurationInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 05:00'!
cmdToggleTrimVersionLists
	<command>
	^ MBToggleTrimVersionListsCommand! !

!MBConfigurationInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 05:00'!
cmdUnloadConfiguration
	<command>
	^ MBUnloadConfigurationCommand! !

!MBConfigurationInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 05:00'!
cmdUpdateFromItsRepository
	<command>
	^ MBUpdateFromItsRepositoryCommand! !

!MBConfigurationInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 05:00'!
cmdValidateConfiguration
	<command>
	^ MBValidateConfigurationCommand! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'AlexandreBergel 1/1/2011 15:36'!
configurationClass
	^ configurationClass! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'dkh 2/23/2011 14:19'!
configurationClass: aConfigurationClass
	configurationClass := aConfigurationClass.
	self name: configurationClass name asString! !

!MBConfigurationInfo methodsFor: 'updating' stamp: 'dkh 03/12/2011 02:24'!
configurationClassModified

	self fullRecalculate ! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'dkh 3/5/2011 18:03'!
configurationInfo

	^self ! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'dkh 3/6/2011 14:50'!
configurationRoot
	^ configurationRoot! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'dkh 3/6/2011 14:50'!
configurationRoot: anObject
	configurationRoot := anObject! !

!MBConfigurationInfo methodsFor: 'accessing-computed' stamp: 'TesterBob 3/26/2011 21:45'!
currentVersion
	"Return the currentVersion of the configuration ... nil if not loaded."

	currentVersion == #notLoaded
		ifTrue: [ ^ nil ].
	(currentVersion ~~ nil and: [ currentVersion ~~ #recalculate])
		ifTrue: [ ^ currentVersion ].
	packages := projects := groups := text := nil.
	self configurationRoot ifNil: [  ^ currentVersion ].
	(currentVersion := self project currentVersion)
		ifNil: [ 
			currentVersion := #notLoaded.
			self configurationRoot announcer announce: (MBConfigurationInfoChanged changed: self).
			^ nil ].
	self configurationRoot announcer announce: (MBConfigurationInfoChanged changed: self).
	^ currentVersion! !

!MBConfigurationInfo methodsFor: 'accessing-computed' stamp: 'dkh 4/7/2011 23:58'!
currentVersion: aVersion

	currentVersion  := aVersion.
	branch := baselines := versions := infoList := packages := projects := groups := text := nil.
	self configurationRoot announcer announce: (MBConfigurationInfoChanged changed: self).
	self announcer announce: (MBInfoListChanged changed: self).
! !

!MBConfigurationInfo methodsFor: 'testing' stamp: 'dkh 3/9/2011 16:30'!
currentVersionMismatch
	^ (self projects anySatisfy: [ :each | each currentVersionMismatch ])
		or: [ self packages anySatisfy: [ :each | each currentVersionMismatch ] ]! !

!MBConfigurationInfo methodsFor: 'utils' stamp: 'dkh 4/7/2011 23:49'!
extractBranchFrom: aWorkingCopy
	| ref |
	(aWorkingCopy isNil or: [ aWorkingCopy ancestors isEmpty ])
		ifTrue: [ ^ '' ].
	ref := GoferVersionReference name: aWorkingCopy ancestors first name.
	^ ref branch! !

!MBConfigurationInfo methodsFor: 'updating' stamp: 'dkh 3/14/2011 11:10'!
fullRecalculate

	super fullRecalculate.
	(currentVersion == #recalculate or: [ currentVersion isNil ]) ifTrue: [^self ].
	currentVersion := #recalculate.
! !

!MBConfigurationInfo methodsFor: 'testing' stamp: 'JPSA 4/20/2012 21:22'!
isDirty
	| wc |
	^ [super isDirty or: [ (wc := self workingCopy) notNil and: [ wc needsSaving ]]] on:Error do:[false].! !

!MBConfigurationInfo methodsFor: 'printing' stamp: 'JPSA 4/20/2012 21:21'!
printOn: aStream
	| cv nameString wc refString branchString |
	[self name
		ifNil: [ 
			aStream nextPutAll: ''.
			^ self ].
	nameString := MBToolBox baseNameOf: self name.
	(refString := self extractPackageSignatureFrom: (wc := self workingCopy)) notEmpty
		ifTrue: [ refString := '(' , refString , ')' ].
	(branchString := self branch) notEmpty
		ifTrue: [ nameString := nameString, '.', branchString ].
	self isDirty
		ifTrue: [ aStream nextPutAll: '* ' ].
	aStream nextPutAll: nameString.
	(cv := self currentVersion) notNil
		ifTrue: [ aStream nextPutAll: ' ' , cv versionString ].
	aStream nextPutAll: refString.] on:Error do:[].! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'dkh 3/10/2011 11:25'!
project
	"Answer the MetacelloProject associated with the receiver."

	^ self configurationClass project! !

!MBConfigurationInfo methodsFor: 'updating' stamp: 'dkh 4/7/2011 23:58'!
recalculate
	branch := workingCopy := baselines := versions := nil.
	super recalculate.
	self configurationRoot announcer announce: (MBConfigurationInfoChanged changed: self).
! !

!MBConfigurationInfo methodsFor: 'updating' stamp: 'dkh 4/12/2011 10:43'!
recalculateIfInterestedInConfigurationInfo: configInfo for: operation

	projects ifNil: [ ^self ].
	self projects detect: [ :info | info interestedInConfigurationInfo: configInfo ] ifNone: [ ^self ].
	infoList := text := projects := nil.
	self configurationRoot announcer announce: (MBConfigurationInfoChanged changed: self)! !

!MBConfigurationInfo methodsFor: 'updating' stamp: 'dkh 4/12/2011 10:51'!
recalculateIfInterestedInPackageNamed: packageName for: operation
	| recalculate |
	recalculate := super recalculateIfInterestedInPackageNamed: packageName for: operation.
	(recalculate not and: [ baselines notNil ])
		ifTrue: [ 
			(self baselines detect: [ :info | info recalculateIfInterestedInPackageNamed: packageName for: operation ] ifNone: [  ])
				ifNotNil: [ recalculate := true ] ].
	(recalculate not and: [ versions notNil ])
		ifTrue: [ 
			(self versions detect: [ :info | info recalculateIfInterestedInPackageNamed: packageName for: operation ] ifNone: [  ])
				ifNotNil: [ recalculate := true ] ].
	(recalculate and: [ operation ~~ #modified ])
		ifTrue: [ 
			currentVersion == #notLoaded
				ifTrue: [ currentVersion := nil ].
			self fullRecalculate ]! !

!MBConfigurationInfo methodsFor: 'initialize-release' stamp: 'dkh 3/6/2011 18:37'!
release

	super release.
	baselines := versions := nil.! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'dkh 3/16/2011 06:03'!
repositories
	"Return the repositories associated with the configuration."

	^self project projectPackage workingCopy repositoryGroup repositories! !

!MBConfigurationInfo methodsFor: 'private' stamp: 'dkh 3/2/2011 08:07'!
trimVersionInfos: versionInfos

	| trimmed count marker cv |
	self trimVersionLists ifFalse: [ ^versionInfos ].
	versionInfos size <= 10 ifTrue: [ ^versionInfos ].
	trimmed := (versionInfos copyFrom: 1 to: 5) asOrderedCollection.
	marker := count := 0.
	cv := self currentVersion.
	 6 to: versionInfos size do: [:index | | info |
		info := versionInfos at: index.
		info isStable | info isBleedingEdge | info isDevelopment | info hasValidationIssues | (cv = info version)
			ifTrue: [ 
				count - 1 >= marker ifTrue: [ trimmed add:( MBLabelInfo new name: '..') ].
				trimmed add: info.
				marker := count. ].
		count := count + 1 ].
	count - 1 >= marker ifTrue: [ trimmed add:( MBLabelInfo new name: '..') ].
	^trimmed! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'dkh 3/1/2011 21:15'!
trimVersionLists

	trimVersionLists == nil ifTrue: [ trimVersionLists := true ].
	^trimVersionLists! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'dkh 3/1/2011 21:15'!
trimVersionLists: aBool

	trimVersionLists := aBool! !

!MBConfigurationInfo methodsFor: 'actions' stamp: 'dkh 2/27/2011 20:26'!
validate
	validationResult == nil
		ifTrue: [ 
			validationIcon := nil.
			validationResult := MetacelloToolBox validateConfiguration: self configurationClass ].
	^ validationResult! !

!MBConfigurationInfo methodsFor: 'actions' stamp: 'dkh 3/6/2011 14:56'!
validateFull

	infoList := baselines := versions := nil.
	(self baselines, self versions) do: [:version | version validateFull ].
	^super validateFull.
! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'dkh 4/8/2011 16:14'!
version

	^self currentVersion! !

!MBConfigurationInfo methodsFor: 'accessing-computed' stamp: 'dkh 3/2/2011 20:29'!
versionForInfoList

	^self currentVersion ! !

!MBConfigurationInfo methodsFor: 'accessing-computed' stamp: 'dkh 3/6/2011 15:32'!
versions
	"Return the versions of the configuration"

	versions ~~ nil
		ifTrue: [ ^ versions ].
	versions := (self project versions reject: [ :vrsn | vrsn blessing == #baseline or: [ vrsn blessing == #broken ] ])
		reversed
		collect: [ :vrsn | 
			(MBVersionInfo version: vrsn)
				configurationInfo: self;
				yourself ].
	^ versions! !

!MBConfigurationInfo methodsFor: 'accessing' stamp: 'dkh 2/27/2011 15:28'!
workingCopy
	| pkg |
	workingCopy ~~ nil ifTrue: [ ^workingCopy ].
	pkg := MCPackage named: self configurationClass category asString.
	pkg  hasWorkingCopy ifFalse: [ ^nil ].
	^workingCopy := pkg workingCopy! !

!MBInfo class methodsFor: 'accessing' stamp: 'dkh 4/10/2011 19:55'!
helpLabel

	self subclassResponsibility! !

!MBInfo class methodsFor: 'accessing' stamp: 'dkh 2/27/2011 19:57'!
validateAll

	ValidateAll == nil ifTrue: [ ValidateAll := false ].
	^ValidateAll! !

!MBInfo class methodsFor: 'accessing' stamp: 'dkh 2/27/2011 19:57'!
validateAll: aBool

	ValidateAll := aBool! !

!MBInfo methodsFor: 'accessing' stamp: 'dkh 3/10/2011 12:37'!
announcer 

	^self configurationRoot announcer! !

!MBInfo methodsFor: 'converting' stamp: 'dkh 3/7/2011 21:47'!
asStringOrText

	^self text! !

!MBInfo methodsFor: 'accessing' stamp: 'dkh 2/26/2011 16:17'!
browseValidationResults

	self validate explore! !

!MBInfo methodsFor: 'accessing' stamp: 'dkh 3/7/2011 21:48'!
buildStringOrText
	^self printString! !

!MBInfo methodsFor: 'actions' stamp: 'dkh 2/26/2011 11:46'!
clearValidationIcon

	validationIcon := nil! !

!MBInfo methodsFor: 'commands' stamp: 'dkh 4/6/2011 15:54'!
cmdUpdateDevPackages
	<command>
	^ MBUpdateDevCommand! !

!MBInfo methodsFor: 'commands' stamp: 'dkh 2/28/2011 16:40'!
commands
	^ (self class allSelectors select:
		[ :k | k beginsWith: 'cmd'  ]) collect: [ :k | self perform: k ]! !

!MBInfo methodsFor: 'accessing' stamp: 'dkh 3/6/2011 14:53'!
configurationInfo

	^self subclassResponsibility ! !

!MBInfo methodsFor: 'accessing' stamp: 'dkh 3/6/2011 14:54'!
configurationRoot

	^self configurationInfo configurationRoot! !

!MBInfo methodsFor: 'utils' stamp: 'dkh 3/20/2011 09:40'!
extractPackageSignatureFrom: aWorkingCopy
	| ref |
	(aWorkingCopy isNil or: [ aWorkingCopy ancestors isEmpty ])
		ifTrue: [ ^ '' ].
	ref := GoferVersionReference name: aWorkingCopy ancestors first name.
	^ ref author , '.' , ref versionNumber asString! !

!MBInfo methodsFor: 'testing' stamp: 'dkh 2/27/2011 16:53'!
interestedInPackageNamed: packageName

	^false! !

!MBInfo methodsFor: 'testing' stamp: 'AlexandreBergel 1/1/2011 15:08'!
isDirty
	^ false! !

!MBInfo methodsFor: 'accessing' stamp: 'AlexandreBergel 1/1/2011 13:14'!
name
	^ name! !

!MBInfo methodsFor: 'accessing' stamp: 'AlexandreBergel 1/1/2011 13:14'!
name: aName
	name := aName! !

!MBInfo methodsFor: 'printing' stamp: 'AlexandreBergel 1/1/2011 14:14'!
printOn: aStream
	self name ifNil: [ aStream nextPutAll: '' . ^ self ].
	aStream nextPutAll: self name! !

!MBInfo methodsFor: 'accessing' stamp: 'dkh 3/2/2011 16:39'!
project
	"Answer the MetacelloProject associated with the receiver."
	
	^nil! !

!MBInfo methodsFor: 'utils' stamp: 'dkh 3/4/2011 12:40'!
repositories
	"Return the repositories associated with the receiver."

	^#()! !

!MBInfo methodsFor: 'accessing' stamp: 'dkh 3/7/2011 21:47'!
text
	text ifNil: [ text := self buildStringOrText ].
	^text! !

!MBInfo methodsFor: 'accessing' stamp: 'dkh 3/7/2011 21:45'!
text: anObject
	text := anObject! !

!MBInfo methodsFor: 'accessing' stamp: 'dkh 2/26/2011 16:16'!
validate

	^#()! !

!MBInfo methodsFor: 'actions' stamp: 'dkh 2/27/2011 20:45'!
validateFull

	self  validationResult: nil.
	^self validate! !

!MBInfo methodsFor: 'accessing' stamp: 'DaleHenrichs 03/08/2011 16:17'!
validationIcon
	(validationResult ~~ nil or: [ self class validateAll ])
		ifTrue: [ 
			validationResult ifNil: [ self validateFull ].
			validationIcon == nil
				ifTrue: [ validationIcon := self perform: #calculateValidationIcon ].
			^ validationIcon ].
	^ self perform: #validateGray! !

!MBInfo methodsFor: 'accessing' stamp: 'dkh 3/6/2011 19:24'!
validationIconSymbol
	(validationResult ~~ nil or: [ self class validateAll ])
		ifTrue: [ 
			validationResult ifNil: [ self validateFull ].
			validationIconSymbol == nil
				ifTrue: [ validationIconSymbol := self calculateValidationIconSymbol ].
			^ validationIconSymbol ].
	^ #validateGray! !

!MBInfo methodsFor: 'accessing' stamp: 'dkh 2/27/2011 19:56'!
validationResult: anObject

	validationResult := anObject! !

MBInfo subclass: #MBLabelInfo
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBLabelInfo methodsFor: 'accessing' stamp: 'dkh 2/26/2011 18:30'!
validate

	^nil! !

!MBLabelInfo methodsFor: 'accessing' stamp: 'dkh 2/27/2011 20:02'!
validationIcon

	^nil! !

!MBLabelInfo methodsFor: 'accessing' stamp: 'dkh 3/6/2011 19:25'!
validationIconSymbol

	^#blank! !

MBInfo subclass: #MBSpecInfo
	instanceVariableNames: 'spec configurationInfo'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBSpecInfo commentStamp: '<historical>' prior: 0!
A MBSpecInfo holds information on Metacello specifications.

Instance Variables
	configurationInfo:		the object holding information on the whole configuration.
	spec:		the specification of this object (a MetacelloSpec).
!

MBSpecInfo subclass: #MBAbstractPackageInfo
	instanceVariableNames: 'packageName workingCopy'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBAbstractPackageInfo commentStamp: '<historical>' prior: 0!
A MBAbstractPackageInfo is an abstraction to represent both project and packages.

Instance Variables
	packageName:		name of the package
	workingCopy:		a MCWorkingCopy representing the version of the package in memory
!

!MBAbstractPackageInfo class methodsFor: 'instance creation' stamp: 'dkh 2/27/2011 15:32'!
named: infoName

	^self named: infoName packageName: infoName spec: nil! !

!MBAbstractPackageInfo class methodsFor: 'instance creation' stamp: 'AlexandreBergel 3/5/2011 21:57'!
named: infoName packageName: packageName spec: aMetacelloSpec
	"Create an instance of myself named infoName for the package named packageName"

	| answer |
	self assert: [ packageName isString ].
	self assert: [ packageName isSymbol not ].
	
	answer := super new.
	answer name: infoName.
	answer packageName: packageName.
	answer spec: aMetacelloSpec.
	^ answer! !

!MBAbstractPackageInfo class methodsFor: 'instance creation' stamp: 'AlexandreBergel 1/16/2011 01:05'!
new
	self error: 'Please, use #named: to create an instance'! !

!MBAbstractPackageInfo methodsFor: 'accessing' stamp: 'AlexandreBergel 3/5/2011 22:57'!
classForBrowsing
	self subclassResponsibility ! !

!MBAbstractPackageInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 05:00'!
cmdBrowse
	<command>
	^ MBBrowsePackageCommand! !

!MBAbstractPackageInfo methodsFor: 'commands' stamp: 'dkh 3/20/2011 10:36'!
cmdBrowsePackageChanges
	<command>
	^ MBPackageChangesCommand
	! !

!MBAbstractPackageInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 05:01'!
cmdOpenRepositoryCommand
	<command>
	^ MBOpenRepositoryCommand! !

!MBAbstractPackageInfo methodsFor: 'testing' stamp: 'DaleHenrichs 2/23/2011 17:29'!
isDirty
	| wc |
	wc := self workingCopy.
	wc ifNil: [ ^false ].
	^wc needsSaving! !

!MBAbstractPackageInfo methodsFor: 'accessing' stamp: 'dkh 2/23/2011 19:02'!
packageName

	^packageName! !

!MBAbstractPackageInfo methodsFor: 'accessing' stamp: 'dkh 2/23/2011 19:02'!
packageName: aString

	packageName := aString! !

!MBAbstractPackageInfo methodsFor: 'accessing' stamp: 'dkh 2/27/2011 15:37'!
workingCopy
	| pkg |
	workingCopy ~~ nil ifTrue: [ ^workingCopy ].
	pkg := MCPackage named: self packageName.
	pkg  hasWorkingCopy ifFalse: [ ^nil ].
	^workingCopy := pkg workingCopy! !

MBAbstractPackageInfo subclass: #MBPackageInfo
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBPackageInfo class methodsFor: 'accessing' stamp: 'dkh 4/10/2011 19:56'!
helpLabel

	^'Package'! !

!MBPackageInfo methodsFor: 'accessing' stamp: 'AlexandreBergel 2/24/2011 14:52'!
basePackageName
	^ self packageName copyUpToLast: #-! !

!MBPackageInfo methodsFor: 'converting' stamp: 'DaleHenrichs 03/09/2011 11:03'!
buildStringOrText
	| string wc loadedPkgName attributes |
	string := super buildStringOrText.
	(wc := self workingCopy) isNil
		ifTrue: [ ^ string ].
	attributes := OrderedCollection new.
	wc ancestry ancestors notEmpty
		ifTrue: [ 
			loadedPkgName := wc ancestry ancestors first name.
			loadedPkgName = self name
				ifFalse: [ 
					(self compareWorkingCopyNamed: loadedPkgName using: #<=)
						ifTrue: [ attributes add: TextColor red ].
					attributes add: TextEmphasis bold ]].
	self isDirty
		ifTrue: [ attributes add: TextEmphasis underlined ].
	attributes notEmpty 
		ifTrue: [ ^ Text string: string attributes: attributes ].
	^ string! !

!MBPackageInfo methodsFor: 'accessing' stamp: 'dkh 3/2/2011 14:11'!
classForBrowsing

	^self workingCopy packageInfo classes anyOne! !

!MBPackageInfo methodsFor: 'commands' stamp: 'dkh 3/20/2011 16:38'!
cmdBrowsePackageHistory
	<command>
	^ MBPackageHistoryCommand
	! !

!MBPackageInfo methodsFor: 'as yet unclassified' stamp: 'JuanPabloSandovalAlcocer 1/4/2012 15:15'!
cmdLoad
	<command>
	^ MBLoadPackageCommand.! !

!MBPackageInfo methodsFor: 'commands' stamp: 'DaleHenrichs 03/07/2011 15:47'!
cmdRevertPackage
	<command>
	^ MBRevertPackageCommand! !

!MBPackageInfo methodsFor: 'commands' stamp: 'DaleHenrichs 03/07/2011 15:36'!
cmdSavePackage
	<command>
	^ MBSavePackageCommand! !

!MBPackageInfo methodsFor: 'testing' stamp: 'dkh 3/3/2011 07:57'!
compareWorkingCopyNamed: wcName using: comarisonOperator
	| fileRef wcRef |
	fileRef := GoferResolvedReference name: self spec file.
	wcRef := GoferResolvedReference name: wcName.
	^ wcRef compare: fileRef using: comarisonOperator! !

!MBPackageInfo methodsFor: 'testing' stamp: 'DaleHenrichs 03/09/2011 17:05'!
currentVersionMismatch
           | wc loadedPkgName |
           (wc := self workingCopy) isNil
                   ifTrue: [ ^ false ].
           wc ancestry ancestors isEmpty
                   ifTrue: [ ^ false ].
           loadedPkgName := wc ancestry ancestors first name.
           loadedPkgName = self name
                   ifTrue: [ ^false ].
            ^ true
! !

!MBPackageInfo methodsFor: 'testing' stamp: 'dkh 3/9/2011 21:49'!
interestedInPackageNamed: aString

	^aString beginsWith: self packageName! !

!MBPackageInfo methodsFor: 'as yet unclassified' stamp: 'JuanPabloSandovalAlcocer 1/4/2012 14:04'!
mbPacakgeName
	| string wc loadedPkgName attributes |
	string := ''.
	(wc := self workingCopy) isNil
		ifTrue: [ ^ string ].
	attributes := OrderedCollection new.
	wc ancestry ancestors notEmpty
		ifTrue: [ 
			loadedPkgName := wc ancestry ancestors first name.
			loadedPkgName = self name
				ifFalse: [ 
					(self compareWorkingCopyNamed: loadedPkgName using: #<=)
						ifTrue: [ attributes add: TextColor red ].
					attributes add: TextEmphasis bold ]].
	self isDirty
		ifTrue: [ attributes add: TextEmphasis underlined ].
	attributes notEmpty 
		ifTrue: [ ^ Text string: string attributes: attributes ].
	^ string! !

!MBPackageInfo methodsFor: 'printing' stamp: 'JuanPabloSandovalAlcocer 1/1/2012 22:57'!
printOn: aStream
	| wc |
	self isDirty
		ifTrue: [ aStream nextPutAll: '* ' ].
	(wc := self workingCopy) isNil
		ifTrue: [ 
			aStream
				nextPutAll: self packageName;
				nextPutAll: ' ---' ]
		ifFalse: [ 
			wc ancestry ancestors notEmpty
				ifTrue: [ 
					| loadedPkgName refString |
					loadedPkgName := wc ancestry ancestors first name.
					(refString := self extractPackageSignatureFrom: wc) notEmpty
						ifTrue: [ refString := '[' , refString , ']' ].
					loadedPkgName = self name
						ifTrue: [ aStream nextPutAll: self name ]
						ifFalse: [ 
							(self compareWorkingCopyNamed: loadedPkgName using: #<=)
								ifTrue: [ refString := Text string: refString attributes: TextColor red ].
							aStream
								nextPutAll: self name;
								nextPutAll: refString ] ] ]! !

!MBPackageInfo methodsFor: 'utils' stamp: 'dkh 3/16/2011 06:03'!
repositories
	"Return the repositories associated with the package."

	^self spec workingCopy repositoryGroup repositories! !

!MBPackageInfo methodsFor: 'accessing' stamp: 'dkh 3/2/2011 21:42'!
typeLabel

	^'package'! !

!MBPackageInfo methodsFor: 'as yet unclassified' stamp: 'JuanPabloSandovalAlcocer 1/8/2012 17:50'!
versions
	""
	|wc v|
	(wc := self workingCopy) isNil
                   ifTrue: [ ^ #() ].
      ^ (wc ancestry breadthFirstAncestors) collect: [ : vi| vi].! !

MBAbstractPackageInfo subclass: #MBProjectInfo
	instanceVariableNames: 'currentVersion'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBProjectInfo class methodsFor: 'accessing' stamp: 'dkh 4/10/2011 19:56'!
helpLabel

	^'Project'! !

!MBProjectInfo methodsFor: 'converting' stamp: 'dkh 3/7/2011 21:53'!
buildStringOrText
	| string cv projectClass info attributes specVersion |
	string := super buildStringOrText.
	attributes := OrderedCollection new.
	self isDirty
		ifTrue: [ attributes add: TextEmphasis underlined ].
	(((projectClass := self spec projectClass) isNil or: [ (cv := self currentVersion) isEmpty ])
		or: [ (specVersion := self spec versionOrNil) isNil ])
		ifTrue: [ 
			attributes notEmpty
				ifTrue: [ ^ Text string: string attributes: attributes ].
			^ string ].
	self currentVersionMismatch
		ifTrue: [ attributes add: TextEmphasis bold ].
	specVersion versionStatus == #somethingLoaded
		ifTrue: [ attributes add: TextColor red ].
	attributes notEmpty
		ifTrue: [ ^ Text string: string attributes: attributes ].
	^ string! !

!MBProjectInfo methodsFor: 'accessing' stamp: 'dkh 3/2/2011 14:08'!
classForBrowsing

	^self spec projectClass! !

!MBProjectInfo methodsFor: 'accessing' stamp: 'dkh 3/6/2011 15:21'!
currentVersion
	currentVersion == nil
		ifTrue: [ 
			| projectClass version info |
			(projectClass := self spec projectClass) == nil
				ifTrue: [ 
					currentVersion := ''.
					^ currentVersion ].
			(info := self configurationRoot configurationInfoFor: projectClass) == nil
				ifTrue: [ 
					currentVersion := ''.
					^ currentVersion ].
			(currentVersion := info currentVersion) == nil
				ifTrue: [ 
					currentVersion := ''.
					^ currentVersion ].
			currentVersion := currentVersion versionString ].
	^ currentVersion! !

!MBProjectInfo methodsFor: 'accessing' stamp: 'dkh 2/23/2011 20:46'!
currentVersion: anObject

	currentVersion := anObject! !

!MBProjectInfo methodsFor: 'testing' stamp: 'DaleHenrichs 03/07/2011 12:32'!
currentVersionMismatch
	| cv specVersion |
	(cv := self currentVersion) notEmpty
		ifTrue: [ 
			(specVersion := self spec versionOrNil) ~~ nil
				ifTrue: [^ cv asMetacelloVersionNumber ~= specVersion versionNumber ]].
	^false! !

!MBProjectInfo methodsFor: 'testing' stamp: 'dkh 4/9/2011 21:05'!
interestedInConfigurationInfo: configInfo
	| projectClass |
	(projectClass := self spec projectClass) == nil
		ifTrue: [ ^ false ].
	^(self configurationRoot configurationInfoFor: projectClass) name = configInfo name
! !

!MBProjectInfo methodsFor: 'testing' stamp: 'dkh 3/6/2011 15:15'!
interestedInPackageNamed: aString
	| projectClass version info |
	(projectClass := self spec projectClass) == nil
		ifTrue: [ ^ false ].
	(aString beginsWith: projectClass name asString)
		ifTrue: [ ^ true ].
	(info := self configurationRoot configurationInfoFor: projectClass) == nil
		ifTrue: [ ^ false ].
	^ info interestedInPackageNamed: aString! !

!MBProjectInfo methodsFor: 'printing' stamp: 'dkh 3/3/2011 08:39'!
printOn: aStream
	| cv specVersion |
	self isDirty
		ifTrue: [ aStream nextPutAll: '* ' ].
	super printOn: aStream.
	(cv := self currentVersion) isEmpty
		ifTrue: [ aStream nextPutAll: ' ---' ]
		ifFalse: [ 
			(specVersion := self spec versionOrNil) ~~ nil
				ifTrue: [ 
					aStream nextPutAll: ' ' , specVersion versionString.
					cv asMetacelloVersionNumber = specVersion versionNumber
						ifFalse: [ aStream nextPutAll: ' [' , cv , ']' ] ] ]! !

!MBProjectInfo methodsFor: 'utils' stamp: 'dkh 3/16/2011 06:04'!
repositories
	"Return the repositories associated with the configuration for the project."

	^self spec projectPackage workingCopy repositoryGroup repositories! !

!MBProjectInfo methodsFor: 'accessing' stamp: 'dkh 3/2/2011 21:42'!
typeLabel

	^'project'! !

!MBProjectInfo methodsFor: 'accessing' stamp: 'dkh 2/27/2011 20:26'!
validate
	validationResult == nil
		ifTrue: [ 
			validationIcon := nil.
			validationResult := self validateIfAbsent: [ #() ] ].
	^ validationResult! !

!MBProjectInfo methodsFor: 'accessing' stamp: 'dkh 2/26/2011 16:23'!
validateIfAbsent: absentBlock

	^MetacelloToolBox validateConfiguration: (Smalltalk 
		at: self packageName asSymbol 
		ifAbsent: absentBlock).
! !

MBSpecInfo subclass: #MBGroupInfo
	instanceVariableNames: 'groupContents'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBGroupInfo commentStamp: '<historical>' prior: 0!
A MBGroupInfo holds information on a group defintiion.

Instance Variables
	groupContents:		an array with group contents as literals .
!

!MBGroupInfo class methodsFor: 'accessing' stamp: 'dkh 4/10/2011 19:57'!
helpLabel

	^'Group'! !

!MBGroupInfo methodsFor: 'accessing' stamp: 'AlexandreBergel 3/27/2011 12:11'!
groupContentsIfLoaded

	| version loadedPackageNames groupPackageNames |
	groupContents ~~ nil ifTrue: [ ^groupContents ].
	groupContents := #().
	self configurationInfo ifNil: [ ^ groupContents ].
	(version := self configurationInfo currentVersion) ifNil: [ ^groupContents ].
	loadedPackageNames := version defaultPackageNamesToLoad: #().
	loadedPackageNames remove: 'default' ifAbsent: [].
	groupPackageNames := (version packagesForSpecNamed: self name) collect: [:spc | spc name ].
	groupPackageNames do: [:nm | (loadedPackageNames includes: nm) ifFalse: [ ^groupContents ] ].
	^groupContents := self spec includes! !

!MBGroupInfo methodsFor: 'accessing' stamp: 'dkh 3/1/2011 11:51'!
name
	^ self spec name! !

!MBGroupInfo methodsFor: 'accessing' stamp: 'dkh 3/1/2011 11:51'!
name: aName

	self shouldNotImplement! !

!MBGroupInfo methodsFor: 'printing' stamp: 'dkh 3/1/2011 20:03'!
printOn: aStream
	| loadedPackageNames |
	super printOn: aStream.
	(loadedPackageNames := self groupContentsIfLoaded) isEmpty
		ifTrue: [ aStream nextPutAll: ' ---' ]
		ifFalse: [ 
			aStream nextPutAll: ' [ '.
			loadedPackageNames do: [:pkgName | aStream nextPutAll: pkgName, ' '  ].
			aStream nextPut: $] ].! !

!MBGroupInfo methodsFor: 'accessing' stamp: 'dkh 3/2/2011 21:42'!
typeLabel

	^'group'! !

!MBSpecInfo class methodsFor: 'instance creation' stamp: 'DaleHenrichs 03/05/2011 11:15'!
spec: aMetacelloSpec
	"Create an instance of myself with the given spec"

	^(super new) spec: aMetacelloSpec! !

!MBSpecInfo methodsFor: 'commands' stamp: 'dkh 3/4/2011 05:00'!
cmdLoadSpecCommand
	<command>
	^ MBLoadPackageCommand! !

!MBSpecInfo methodsFor: 'accessing' stamp: 'dkh 3/5/2011 18:05'!
configurationInfo
	^ configurationInfo! !

!MBSpecInfo methodsFor: 'accessing' stamp: 'dkh 3/5/2011 18:05'!
configurationInfo: anObject
	configurationInfo := anObject! !

!MBSpecInfo methodsFor: 'testing' stamp: 'DaleHenrichs 03/07/2011 12:38'!
currentVersionMismatch

	^false! !

!MBSpecInfo methodsFor: 'testing' stamp: 'JuanPabloSandovalAlcocer 1/1/2012 23:22'!
isDirty
	| wc |
	wc := self workingCopy.
	wc ifNil: [ ^false ].
	^wc needsSaving! !

!MBSpecInfo methodsFor: 'accessing' stamp: 'dkh 3/1/2011 11:57'!
packageName

	^self name! !

!MBSpecInfo methodsFor: 'accessing' stamp: 'dkh 3/2/2011 16:43'!
project
	"Answer the MetacelloProject associated with the receiver."
	
	^self spec project! !

!MBSpecInfo methodsFor: 'accessing' stamp: 'dkh 3/1/2011 11:46'!
spec

	^spec! !

!MBSpecInfo methodsFor: 'accessing' stamp: 'dkh 3/1/2011 11:46'!
spec: aMetacelloSpec

	spec := aMetacelloSpec ! !

!MBSpecInfo methodsFor: 'accessing' stamp: 'dkh 3/2/2011 21:41'!
typeLabel

	^''! !

!MBSpecInfo methodsFor: 'accessing' stamp: 'dkh 3/1/2011 11:47'!
validate

	^nil! !

!MBSpecInfo methodsFor: 'accessing' stamp: 'dkh 3/1/2011 11:47'!
validationIcon

	^nil! !

!MBSpecInfo methodsFor: 'accessing' stamp: 'dkh 3/6/2011 19:25'!
validationIconSymbol

	^#blank! !

Object subclass: #MBPlatform
	instanceVariableNames: 'defaultBrowser'
	classVariableNames: 'Current'
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBPlatform class methodsFor: 'accessing' stamp: 'dkh 4/8/2011 20:18'!
current
	Current
		ifNil: [Current := MBPlatform new].
	^ Current! !

!MBPlatform class methodsFor: 'initialize-release' stamp: 'dkh 3/4/2011 11:40'!
initialize
	"MBPlatform initialize"

	Current := self new! !

!MBPlatform methodsFor: 'code browsing' stamp: 'JuanPabloSandovalAlcocer 6/30/2012 19:55'!
browseMethodForVersion: aMetacelloVersion

	| cm |
	cm := MBToolBox compiledMethodForVersion: aMetacelloVersion.
	^(Smalltalk at: #Browser) perform: #newOnClass:selector: with: cm methodClass with: cm selector! !

!MBPlatform methodsFor: 'monticello' stamp: 'DaleHenrichs 03/22/2011 13:01'!
browseVersionHistoryFor: aConfigurationInfo

	((Smalltalk at: #MCVersionHistoryBrowser) new ancestry: aConfigurationInfo workingCopy ancestors first) perform: #show! !

!MBPlatform methodsFor: 'user interaction' stamp: 'dkh 3/4/2011 12:29'!
chooseFrom: aList

	^(Smalltalk at: #UIManager) default chooseFrom: aList! !

!MBPlatform methodsFor: 'user interaction' stamp: 'dkh 04/05/2011 20:08'!
chooseFrom: choices message: aString

	| ans |
	ans := self chooseFrom: choices values: choices title: aString.
	ans ifNil: [^nil].
	^choices indexOf: ans! !

!MBPlatform methodsFor: 'user interaction' stamp: 'dkh 3/20/2011 10:23'!
chooseFrom: labelList values: valueList lines: linesArray title: aString

	^ (Smalltalk at: #UIManager) default chooseFrom: labelList values: valueList lines: linesArray title: aString! !

!MBPlatform methodsFor: 'user interaction' stamp: 'AlexandreBergel 3/5/2011 22:43'!
chooseFrom: labels values: values title: message

	^ (Smalltalk at: #UIManager) default chooseFrom: labels values: values title: message! !

!MBPlatform methodsFor: 'user interaction' stamp: 'dkh 3/4/2011 14:45'!
confirm: aString

	^super confirm: aString! !

!MBPlatform methodsFor: 'default browser' stamp: 'dkh 4/6/2011 10:40'!
defaultBrowser
	defaultBrowser
		ifNil: [ 
			Smalltalk at: #MBOBConfigurationBrowser ifPresent: [ :cl | defaultBrowser := cl ].
			Smalltalk at: #Versionner ifPresent: [ :cl | defaultBrowser := cl ] ].
	^ defaultBrowser! !

!MBPlatform methodsFor: 'default browser' stamp: 'dkh 4/6/2011 10:40'!
defaultBrowser: aBrowserClass
	defaultBrowser := aBrowserClass! !

!MBPlatform methodsFor: 'user interaction' stamp: 'dkh 4/6/2011 15:17'!
edit: aString

	self edit: aString label: nil! !

!MBPlatform methodsFor: 'user interaction' stamp: 'dkh 4/6/2011 15:16'!
edit: aString label: labelString

	(Smalltalk at: #UIManager) default edit: aString label: labelString! !

!MBPlatform methodsFor: 'changes' stamp: 'dkh 3/20/2011 11:19'!
findChangesBetween: versionSnapshot toLabel: toLabel and: ancestorVersionSnapshot fromLabel: fromLabel

	| patch |
		patch := versionSnapshot patchRelativeToBase: ancestorVersionSnapshot.
		patch isNil ifTrue: [^ self].
		patch isEmpty
			ifTrue: [
				self inform: 'No changes' ]
			ifFalse: [
				self
					viewChanges: patch
					from: fromLabel
					to: toLabel
					title: 'Changes between ', fromLabel, ' and ', toLabel   ]! !

!MBPlatform methodsFor: 'changes' stamp: 'dkh 3/4/2011 12:05'!
findChangesFor: workingCopy relativeToRepository: repository
	| patch |
	repository == nil
		ifTrue: [ ^ self ].
	patch := workingCopy changesRelativeToRepository: repository.
	patch isNil
		ifTrue: [ ^ self ].
	patch isEmpty
		ifTrue: [ 
			workingCopy modified: false.
			self inform: 'No changes' ]
		ifFalse: [ 
			workingCopy modified: true.
			self
				viewChanges: patch
				from: workingCopy packageName , ' (' , workingCopy ancestry ancestorString , ')'
				to: ('Modified {1}' translated format: {(workingCopy description)}) ]! !

!MBPlatform methodsFor: 'transactions' stamp: 'dkh 4/6/2011 10:08'!
inTransactionDo: aBlock

	^aBlock value! !

!MBPlatform methodsFor: 'user interaction' stamp: 'dkh 3/5/2011 09:31'!
inform: aString

	^super inform: aString! !

!MBPlatform methodsFor: 'user interaction' stamp: 'JuanPabloSandovalAlcocer 6/30/2012 20:02'!
multilineRequest: request initialAnswer: initial
	
	^(Smalltalk at: #UIManager) default 
		perform: #multiLineRequest:initialAnswer:answerHeight:
		withArguments: {request. initial. 200. }
! !

!MBPlatform methodsFor: 'repositories' stamp: 'dkh 4/8/2011 15:58'!
newRepository

	| types index |
	types := MCRepository allConcreteSubclasses asArray.
	index := self chooseFrom: (types collect: [:ea | ea description])
				message: 'Repository type:'.
	^ index = 0 ifFalse: [(types at: index) perform: #morphicConfigure]! !

!MBPlatform methodsFor: 'repositories' stamp: 'DaleHenrichs 03/08/2011 16:11'!
openRepository: aMonticelloRepository

	aMonticelloRepository perform: #morphicOpen! !

!MBPlatform methodsFor: 'user interaction' stamp: 'dkh 3/4/2011 12:29'!
request: aString
	^(Smalltalk at: #UIManager) default request: aString! !

!MBPlatform methodsFor: 'user interaction' stamp: 'dkh 3/4/2011 16:13'!
request: aString initialAnswer: initial
	^(Smalltalk at: #UIManager) default request: aString initialAnswer: initial! !

!MBPlatform methodsFor: 'user interaction' stamp: 'AlexandreBergel 3/5/2011 23:17'!
requestPassword: msg

	^(Smalltalk at: #UIManager) default requestPassword: msg! !

!MBPlatform methodsFor: 'cursor' stamp: 'DaleHenrichs 03/08/2011 16:11'!
showExecuteWhile: aBlock

	^((Smalltalk at: #Cursor) execute) perform: #showWhile: with: aBlock! !

!MBPlatform methodsFor: 'changes' stamp: 'dkh 3/4/2011 12:11'!
viewChanges: patch from: fromDescription to: toDescription
	"Open a browser on the given patch."

	self viewChanges: patch from: fromDescription to: toDescription title: ('Changes to {1}' translated format: {fromDescription})! !

!MBPlatform methodsFor: 'changes' stamp: 'DaleHenrichs 03/08/2011 16:10'!
viewChanges: patch from: fromDescription to: toDescription title: title
	"Open a browser on the given patch."

	Smalltalk
		at: #PSMCPatchMorph
		ifPresent: [ :cl | 
			((cl respondsTo: #usedByDefault) and: [ cl perform: #usedByDefault "sent but not implemented in GemStone" ])
				ifTrue: [ 
					^ ((cl perform: #forPatch: with: patch)
						perform: #fromDescription: with: fromDescription;"sent but not implemented in GemStone"
						perform: #toDescription: with: toDescription;
						perform: #newWindow) 
						perform: #title: with: title;
						open ]
				ifFalse: [ 
					"We use a perform to not make Lint complain if the method does not exist"
					((Smalltalk at: #Preferences) 
						perform: #useNewDiffToolsForMC)
						ifTrue: [ 
							^ (((Smalltalk at: #PSMCPatchMorph) perform: #forPatch: with: patch) perform: #newWindow)
								perform: #title: with: title; "sent but not implemented in GemStone"
								open ] ] ].
	Smalltalk
		at: #MCPatchBrowser
		ifPresent: [ :cl | 
			^ (cl perform: #forPatch: with: patch)
				label: title;
				perform: #show; "sent but not implemented in GemStone"
				yourself ].
	self error: 'No patch browser available'! !

Object subclass: #MBToolBox
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Versionner-Core-Model'!

!MBToolBox commentStamp: 'dkh 2/23/2011 15:43' prior: 0!
This class houses methods that should be added to MetacelloToolBox.

At times this class will have no methods implemented, as the methods make their way into MetacelloToolBox.
!

!MBToolBox class methodsFor: 'accessing' stamp: 'dkh 2/23/2011 15:44'!
baseNameOf: configurationClassName
	"Return the baseName for the given configuration class name."

	<apiDocumentation>
	^ (configurationClassName indexOfSubCollection: 'ConfigurationOf') = 0
		ifTrue: [ configurationClassName ]
		ifFalse: [ configurationClassName copyFrom: ('ConfigurationOf' size + 1) to: configurationClassName size]! !

!MBToolBox class methodsFor: 'accessing' stamp: 'dkh 2/23/2011 15:44'!
baseNameOfConfiguration: aConfigurationClass
	"Return the baseName for the given configuration class."

	<apiDocumentation>
	^self baseNameOf: aConfigurationClass name asString! !

!MBToolBox class methodsFor: 'accessing' stamp: 'dkh 2/23/2011 15:44'!
compiledMethodForVersion: aMetacelloVersion

	| toolbox pragma |
	toolbox := MetacelloToolBox new project: aMetacelloVersion project.
	pragma := (toolbox constructor extractAllVersionPragmas at: aMetacelloVersion versionString ifAbsent: [ ^ nil ]) first.
	^pragma method! !

!MBToolBox class methodsFor: 'accessing' stamp: 'DaleHenrichs 03/07/2011 15:32'!
savePackage: aPackageSpec description: commitMessage
	"Save a new version of the mcz file for the given package spec."
	
	<apiDocumentation>
	aPackageSpec goferCommitPackage: commitMessage
! !

!MBToolBox class methodsFor: 'action' stamp: 'dkh 2/28/2011 14:06'!
updateDevelopment: developmentVersionString for: configurationBasename updateProjects: updateProjects description: message
	"Update packageSpecs and (conditionally) the project specs in the given version to reflect the new mcz file and project versions.
	
	  Change from standard toolbox:
		- commit method if message isn't empty.
	"

	<apiDocumentation>
	| toolbox updatedSpecs |
	toolbox := MetacelloToolBox configurationNamed: configurationBasename.
	updatedSpecs := toolbox
		updateVersionMethodForVersion: developmentVersionString
		updateProjects: updateProjects
		updatePackages: true
		versionSpecsDo: [ :attribute :versionSpec | 
			attribute == #common
				ifTrue: [ 
					"update the author, description and timeStamp"
					versionSpec
						author: MetacelloPlatform current authorName;
						timestamp: MetacelloPlatform current timestamp.
					MetacelloToolBox appendDescription: message to: versionSpec ].
			true ].
	(updatedSpecs notEmpty and: [ message notEmpty ])
		ifTrue: [ toolbox commitMethod ].
	^ updatedSpecs! !
MBPlatform initialize!
